/**
 * @file floating-labels.js
 *
 * Select change handler for the floating labels and set select width when it's narrower than the label.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.behaviors.floatingLabels = {
    attach: function attach(context) {
      // For IE11 and old Edge we will fallback to placeholders - labels are
      // hidden in CSS and here we will apply labels values to placeholders.
      if (/Trident/.test(navigator.userAgent) || /Edge/.test(navigator.userAgent)) {
        $('.form--floating-labels', context).once('floating-labels').each(function () {
          $(this).find('.form-group--floating-label:not(.form-no-label) .form-control').each(function (i, el) {
            var label = el.parentNode.querySelector('label').innerText;
            if (el.required) {
              label += ' *';
            }
            el.setAttribute('placeholder', label);
          });
        });

        // There is no point executing the rest of behavior for IE/Edge
        // browsers.
        return;
      }

      // Fixes the width of the form controls if the label is wider than the
      // form control.
      $('.form--floating-labels', context).once('floating-labels').each(function () {
        $(this).find('.form-group--floating-label:not(.form-no-label)').each(function (i, el) {
          var control = el.querySelector('.form-control, .form-select');
          var label = el.querySelector('label');
          if (control.offsetWidth < label.offsetWidth) {
            var paddingRight = parseFloat(window.getComputedStyle(control).getPropertyValue('padding-right'));
            var adjustedWidth = label.offsetWidth + paddingRight;
            // Respect maximum parent width (when controls are in the grid,
            // etc).
            if (adjustedWidth > this.offsetWidth) {
              adjustedWidth -= paddingRight;
            }
            control.style.width = adjustedWidth + 'px';
          }

          if (control.classList.contains('form-select')) {
            // We need to add a helper class when the select changes, so we can
            // style the floating labels.
            control.addEventListener('change', function() {
              if (this.value !== '') {
                control.classList.add('select-filled');
              }
              else {
                control.classList.remove('select-filled');
              }
            });
          }
        });
      });
    }
  };

}(jQuery, Drupal));
